@@ -147,31 +147,6 @@ four_ints_from_obj(PyObject *obj, int *val1, int *val2, int *val3, int *val4)
     return 1;
 }
 
-PyObject *
-pg_tuple_from_values_int(int val1, int val2)
-{
-    PyObject *tup = PyTuple_New(2);
-    if (!tup) {
-        return NULL;
-    }
-
-    PyObject *tmp = PyLong_FromLong(val1);
-    if (!tmp) {
-        Py_DECREF(tup);
-        return NULL;
-    }
-    PyTuple_SET_ITEM(tup, 0, tmp);
-
-    tmp = PyLong_FromLong(val2);
-    if (!tmp) {
-        Py_DECREF(tup);
-        return NULL;
-    }
-    PyTuple_SET_ITEM(tup, 1, tmp);
-
-    return tup;
-}
-
 static PyObject *
 _pg_rect_subtype_new4(PyTypeObject *type, int x, int y, int w, int h)
 {
@@ -619,15 +594,92 @@ pg_rect_collidepoint(pgRectObject *self, PyObject *args)
 }
 
 static PyObject *
-pg_rect_colliderect(pgRectObject *self, PyObject *args)
+pg_rect_colliderect(pgRectObject *self, PyObject *const *args,
+                    Py_ssize_t nargs)
 {
-    SDL_Rect *argrect, temp;
+    /* This function got changed to use the FASTCALL calling convention in
+     * Python 3.7. This lets us exploit the fact that we don't have an
+     * intermediate Tuple args object to extract all the arguments from, saving
+     * us performance in the process. This decoupling forces us to deal with
+     * all the different cases (dictated by the number of parameters) by
+     * building specific code paths.
+     * Given that this function accepts any Rect-like object, there are 3 main
+     * cases to deal with:
+     * - 1 parameter: a Rect-like object
+     * - 2 parameters: two sequences that represent the position and dimensions
+     * of the Rect
+     * - 4 parameters: four numbers that represent the position and dimensions
+     */
 
-    if (!(argrect = pgRect_FromObject(args, &temp))) {
-        return RAISE(PyExc_TypeError, "Argument must be rect style object");
+    SDL_Rect srect = self->r;
+    SDL_Rect temp;
+
+    if (nargs == 1) {
+        /* One argument was passed in, so we assume it's a rectstyle object.
+         * This could mean several of the following (all dealt by
+         * pgRect_FromObject):
+         * - (x, y, w, h)
+         * - ((x, y), (w, h))
+         * - Rect
+         * - Object with "rect" attribute
+         */
+        SDL_Rect *tmp;
+        if (!(tmp = pgRect_FromObject(args[0], &temp))) {
+            if (PyErr_Occurred()) {
+                return NULL;
+            }
+            else {
+                return RAISE(PyExc_TypeError,
+                             "Invalid rect, all 4 fields must be numeric");
+            }
+        }
+        return PyBool_FromLong(_pg_do_rects_intersect(&srect, tmp));
     }
-    return PyBool_FromLong(_pg_do_rects_intersect(&self->r, argrect));
+    else if (nargs == 2) {
+        /* Two separate sequences were passed in:
+         * - (x, y), (w, h)
+         */
+        if (!pg_TwoIntsFromObj(args[0], &temp.x, &temp.y) ||
+            !pg_TwoIntsFromObj(args[1], &temp.w, &temp.h)) {
+            if (PyErr_Occurred())
+                return NULL;
+            else
+                return RAISE(PyExc_TypeError,
+                             "Invalid rect, all 4 fields must be numeric");
+        }
+    }
+    else if (nargs == 4) {
+        /* Four separate arguments were passed in:
+         * - x, y, w, h
+         */
+        if (!(pg_IntFromObj(args[0], &temp.x))) {
+            return RAISE(PyExc_TypeError,
+                         "Invalid x value for rect, must be numeric");
+        }
+
+        if (!(pg_IntFromObj(args[1], &temp.y))) {
+            return RAISE(PyExc_TypeError,
+                         "Invalid y value for rect, must be numeric");
+        }
+
+        if (!(pg_IntFromObj(args[2], &temp.w))) {
+            return RAISE(PyExc_TypeError,
+                         "Invalid w value for rect, must be numeric");
+        }
+
+        if (!(pg_IntFromObj(args[3], &temp.h))) {
+            return RAISE(PyExc_TypeError,
+                         "Invalid h value for rect, must be numeric");
+        }
+    }
+    else {
+        return RAISE(PyExc_ValueError,
+                     "Incorrect arguments number, must be either 1, 2 or 4");
+    }
+
+    return PyBool_FromLong(_pg_do_rects_intersect(&srect, &temp));
 }
+PG_WRAP_FASTCALL_FUNC(pg_rect_colliderect, pgRectObject)
 
 static PyObject *
 pg_rect_collidelist(pgRectObject *self, PyObject *args)
@@ -1311,8 +1363,8 @@ static struct PyMethodDef pg_rect_methods[] = {
      DOC_RECTUNIONALLIP},
     {"collidepoint", (PyCFunction)pg_rect_collidepoint, METH_VARARGS,
      DOC_RECTCOLLIDEPOINT},
-    {"colliderect", (PyCFunction)pg_rect_colliderect, METH_VARARGS,
-     DOC_RECTCOLLIDERECT},
+    {"colliderect", (PyCFunction)PG_FASTCALL_NAME(pg_rect_colliderect),
+     PG_FASTCALL, DOC_RECTCOLLIDERECT},
     {"collidelist", (PyCFunction)pg_rect_collidelist, METH_VARARGS,
      DOC_RECTCOLLIDELIST},
     {"collidelistall", (PyCFunction)pg_rect_collidelistall, METH_VARARGS,
@@ -1876,7 +1928,7 @@ pg_rect_setcentery(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_gettopleft(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x, self->r.y);
+    return pg_tuple_couple_from_values_int(self->r.x, self->r.y);
 }
 
 static int
@@ -1903,7 +1955,7 @@ pg_rect_settopleft(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_gettopright(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x + self->r.w, self->r.y);
+    return pg_tuple_couple_from_values_int(self->r.x + self->r.w, self->r.y);
 }
 
 static int
@@ -1930,7 +1982,7 @@ pg_rect_settopright(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getbottomleft(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x, self->r.y + self->r.h);
+    return pg_tuple_couple_from_values_int(self->r.x, self->r.y + self->r.h);
 }
 
 static int
@@ -1957,8 +2009,8 @@ pg_rect_setbottomleft(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getbottomright(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x + self->r.w,
-                                    self->r.y + self->r.h);
+    return pg_tuple_couple_from_values_int(self->r.x + self->r.w,
+                                           self->r.y + self->r.h);
 }
 
 static int
@@ -1985,7 +2037,8 @@ pg_rect_setbottomright(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getmidtop(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x + (self->r.w >> 1), self->r.y);
+    return pg_tuple_couple_from_values_int(self->r.x + (self->r.w >> 1),
+                                           self->r.y);
 }
 
 static int
@@ -2012,7 +2065,8 @@ pg_rect_setmidtop(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getmidleft(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x, self->r.y + (self->r.h >> 1));
+    return pg_tuple_couple_from_values_int(self->r.x,
+                                           self->r.y + (self->r.h >> 1));
 }
 
 static int
@@ -2039,8 +2093,8 @@ pg_rect_setmidleft(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getmidbottom(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x + (self->r.w >> 1),
-                                    self->r.y + self->r.h);
+    return pg_tuple_couple_from_values_int(self->r.x + (self->r.w >> 1),
+                                           self->r.y + self->r.h);
 }
 
 static int
@@ -2067,8 +2121,8 @@ pg_rect_setmidbottom(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getmidright(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x + self->r.w,
-                                    self->r.y + (self->r.h >> 1));
+    return pg_tuple_couple_from_values_int(self->r.x + self->r.w,
+                                           self->r.y + (self->r.h >> 1));
 }
 
 static int
@@ -2095,8 +2149,8 @@ pg_rect_setmidright(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getcenter(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.x + (self->r.w >> 1),
-                                    self->r.y + (self->r.h >> 1));
+    return pg_tuple_couple_from_values_int(self->r.x + (self->r.w >> 1),
+                                           self->r.y + (self->r.h >> 1));
 }
 
 static int
@@ -2123,7 +2177,7 @@ pg_rect_setcenter(pgRectObject *self, PyObject *value, void *closure)
 static PyObject *
 pg_rect_getsize(pgRectObject *self, void *closure)
 {
-    return pg_tuple_from_values_int(self->r.w, self->r.h);
+    return pg_tuple_couple_from_values_int(self->r.w, self->r.h);
 }
 
 static int
@@ -2195,7 +2249,7 @@ static PyGetSetDef pg_rect_getsets[] = {
 };
 
 static PyTypeObject pgRect_Type = {
-    PyVarObject_HEAD_INIT(NULL, 0).tp_name = "pygame.Rect",
+    PyVarObject_HEAD_INIT(NULL, 0).tp_name = "pygame.rect.Rect",
     .tp_basicsize = sizeof(pgRectObject),
     .tp_dealloc = (destructor)pg_rect_dealloc,
     .tp_repr = (reprfunc)pg_rect_repr,
